==> atmelwlandriver-3.3.5.6.tar.bz2: atmelwlandriver/src/apps/cmd_line/strdefs.h <==
#ifndef __STRDEFS_H__
#define __STRDEFS_H__



#ifdef LOW_RES
#define WIDTH 70
#define HEIGHT 3
#define WINHEIGHT 18
#else
#define WIDTH 78
#define HEIGHT 3
#define WINHEIGHT 18
#endif // LOW_RES

/* Macros for Grouping Basic functionalities */

#define WATTR(WIN, ATTR, INSIDE) \
    wattron(WIN, ATTR);\
    INSIDE\
    wattroff(WIN, ATTR);

#define CENTER(WIN, Y, STR) \
    mvwhline(WIN, Y, 1, ' ', WIDTH-2); \
    mvwprintw(WIN, Y, (WIDTH-strlen(STR))/2, STR);

#define HEADER(WIN, STR) \
    WATTR( WIN, A_BOLD | COLOR_PAIR(2), \
    CENTER( WIN, 1, STR) ) \
    mvwhline(WIN, 2, 1, ACS_HLINE, WIDTH-2); 


/* Default String Definitions */

#ifdef ATMEL
static const char CompanyName[] = "ATMEL";
#elif defined(SMARTBRIDGES)
static const char CompanyName[] = "SmartBridges";
#endif

static const char *conf_choices[] = {
	"Select SSID name (max 32 characters)",
	"Select Channel",
	"Select Radio State",
	"Select International Roaming State",
	"Select Transmit Rate",
	"Select Operating Mode",
	"Select Preamble Type",
	"Select Power Mgmt Mode",
	"Select Fragmentation Threshold",
	"Select Rts Threshold",
	"Exit   Menu",
};

static const char *wep_choices[] = {
             "Set    Wep Level",
	     "Set    Transmission Key",
             "Set    Wep Key Value",
/*
             "Set    Wep Mode",
*/           "Set    Authentication type",
             "Exit   Menu",
                  };

static const char *choices[] = {
//	"View Configuration",
	"View Config",
	"Advanced",
  "Security",
	"Configure Card",
  "Site Survey",
	"Exit",
};

static const char *nychoice[] = { "No", "Yes" };
static const char *opermode[] = { "Ad-hoc", "Infrastr" };


#endif //__STRDEFS_H__

==> atmelwlandriver-3.4.1.0.tar.bz2: atmelwlandriver/src/apps/cmd_line/strdefs.h <==
#ifndef __STRDEFS_H__
#define __STRDEFS_H__



#ifdef LOW_RES
#define WIDTH 70
#define HEIGHT 3
#define WINHEIGHT 18
#else
#define WIDTH 78
#define HEIGHT 3
#define WINHEIGHT 18
#endif // LOW_RES

/* Macros for Grouping Basic functionalities */

#define WATTR(WIN, ATTR, INSIDE) \
    wattron(WIN, ATTR);\
    INSIDE\
    wattroff(WIN, ATTR);

#define CENTER(WIN, Y, STR) \
    mvwhline(WIN, Y, 1, ' ', WIDTH-2); \
    mvwprintw(WIN, Y, (WIDTH-strlen(STR))/2, STR);

#define HEADER(WIN, STR) \
    WATTR( WIN, A_BOLD | COLOR_PAIR(2), \
    CENTER( WIN, 1, STR) ) \
    mvwhline(WIN, 2, 1, ACS_HLINE, WIDTH-2); 


/* Default String Definitions */

#ifdef ATMEL
static const char CompanyName[] = "ATMEL";
#elif defined(SMARTBRIDGES)
static const char CompanyName[] = "SmartBridges";
#endif

#ifdef CALLER_COFVNET
static const char *conf_choices[] = {
	"Select SSID name (max 32 characters)",
	"Select Channel",
	"Select Radio State",
	"Select International Roaming State",
	"Select Transmit Rate",
	"Select Operating Mode",
	"Select Preamble Type",
	"Select Power Mgmt Mode",
	"Select Fragmentation Threshold",
	"Select Rts Threshold",
	"Exit   Menu",
};

static const char *choices[] = {
//	"View Configuration",
	"View Config",
	"Advanced",
  "Security",
	"Configure Card",
  "Site Survey",
	"Exit",
};

static const char *offon[] = { "Off", "On" };
static const char *dis_enable[] = { "Disable", "Enable" };
static const char *powermode[] = { "Active", "Power Save", "Smart P. Save" };
static const char *txrate[] = { "1Mbps", "2Mbps", "5.5Mbps", "11Mbps", "Auto" };
#endif // caller == cofvnet

#ifdef CALLER_SETS
static const char *wep_choices[] = {
             "Set    Wep Level",
	     "Set    Transmission Key",
             "Set    Wep Key Value",
//             "Set    Wep Mode",
             "Set    Authentication type",
             "Exit   Menu",
	};

static const long frequency_list[] = { 2412, 2417, 2422, 2427, 2432, 2437, 2442,

				2447, 2452, 2457, 2462, 2467, 2472, 2484 };

#else		// caller != sets.c
static const char *opermode[] = { "Ad-hoc", "Infrastructure" };
#endif		  // caller == sets.c

#ifdef CALLER_SURVEY
static const char *nychoice[] = { "No", "Yes" };
#else	// caller != survey.c
#endif		// caller == survey.c




#endif //__STRDEFS_H__
